@@ -2,6 +2,7 @@ import argparse
 import pandas as pd
 import numpy as np
 import os
+import pkgutil
 
 class addone(object):
 
@@ -12,6 +13,8 @@ class addone(object):
     def addtest(self):
         print(self.number + 1)
         print('Random numpy integer: ' + str(np.random.randint(4)))
+        data = pkgutil.get_data(__name__, 'data/sample_data.csv')
+        print(data)
         sample_df = pd.DataFrame(pd.read_csv('sample_data.csv'))
         print(sample_df.to_markdown())
 
